@@ -294,6 +294,7 @@ def change_key_permissions(container: Container, keyFile: str, **kwargs):
     )
     container.exec_run(f'sudo cp "{keyFile}" "{keyFile}.CONTAINER"')
     container.exec_run(f'sudo chown 1000:1000 "{keyFile}.CONTAINER"')
+    container.exec_run(f'sudo chmod 600 "{keyFile}.CONTAINER"')
 
 
 def stop_container(container, **kwargs):
@@ -318,15 +319,14 @@ def create_volume(client: docker.client.APIClient, name: str) -> Volume:
     return client.volumes.create(f"{name}-{generate_random_string()}")
 
 
-def push_image(client: docker.client.APIClient, registry: str, image: Image) -> None:
+def push_image(client: docker.client.APIClient, image: Image) -> None:
     toPush = image.tags[0]
-    if registry is not None:
-        toPush = f"{registry}/{toPush}"
-        image.tag(toPush)
 
     try:
+        _LOGGER.info(f"Pushing `{toPush}` image to registry....")
         # this can also return a generator to be used for a progress bar
         client.images.push(toPush)
+        _LOGGER.info(f"Done pushing `{toPush}`")
     except:
         _LOGGER.error(
             "Failed to push the image to the registry, are you sure you have properly authenticated with the remote registry"
@@ -530,8 +530,13 @@ def sync_wiki_repo(host: str, **kwargs) -> None:
     _LOGGER.warning(
         "Syncing all the wiki content from the git repository, this may take a while..."
     )  # noqa: E501
-    api_call(host, query, **kwargs)
-    _LOGGER.warning("Done syncing wiki content")
+    try:
+        api_call(host, query, **kwargs)
+        _LOGGER.warning("Done syncing wiki content")
+    except:
+        error_message = get_wiki_storage_status(host, **kwargs)
+        _LOGGER.error(f"Failed to sync the wiki: {error_message}")
+        raise Exception("Failed to sync the wiki")
 
 
 def import_wiki_repo(host: str, **kwargs):
@@ -546,8 +551,30 @@ def import_wiki_repo(host: str, **kwargs):
     _LOGGER.warning(
         "Importing all the wiki content from the git repository, this may take a while..."
     )  # noqa: E501
-    api_call(host, query, **kwargs)
-    _LOGGER.warning("Done importing wiki content")
+    try:
+        api_call(host, query, **kwargs)
+        _LOGGER.warning("Done importing wiki content")
+    except:
+        error_message = get_wiki_storage_status(host, **kwargs)
+        _LOGGER.error(f"Failed to import the wiki: {error_message}")
+        raise Exception("Failed to import the wiki")
+
+
+def get_wiki_storage_status(host: str, **kwargs) -> str:
+    query = """{
+        storage {
+            status {
+            key
+            status
+            message
+            }
+        }
+    }"""
+
+    _LOGGER.info("Getting the status of the wiki storage...")  # noqa: E501
+    message = api_call(host, query, **kwargs)
+    _LOGGER.info("Done fetching the wiki status")
+    return message
 
 
 def set_wiki_comments(host: str, enabled: bool, **kwargs):
@@ -700,7 +727,7 @@ def dissable_api(host: str, **kwargs) -> None:
     api_call(host, query, **kwargs)
 
 
-def api_call(host: str, query: str, variables: dict = {}, port: int = 3000) -> None:
+def api_call(host: str, query: str, variables: dict = {}, port: int = 3000) -> str:
     headers = {"Authorization": f"Bearer {API_TOKEN}"}
 
     body = {"query": query, "variables": variables}
@@ -708,12 +735,19 @@ def api_call(host: str, query: str, variables: dict = {}, port: int = 3000) -> N
     r = requests.post(f"http://{host}:{port}/graphql", json=body, headers=headers)
 
     payload = r.json()
-    payload = payload["data"][list(payload["data"].keys())[0]]
-    succeeded = payload[list(payload.keys())[0]]["responseResult"]["succeeded"]
-    message = payload[list(payload.keys())[0]]["responseResult"]["message"]
+
+    if "responseResult" in query:
+        payload = payload["data"][list(payload["data"].keys())[0]]
+        succeeded = payload[list(payload.keys())[0]]["responseResult"]["succeeded"]
+        message = payload[list(payload.keys())[0]]["responseResult"]["message"]
+    else:
+        payload = payload["data"][list(payload["data"].keys())[0]]
+        succeeded = True
+        message = payload[list(payload.keys())[0]][0]["message"]
 
     if r.status_code == 200 and succeeded:
-        _LOGGER.info(message or "API call was successful")
+        _LOGGER.debug(message or "API call was successful")
+        return message
     else:
         _LOGGER.error(json.dumps(r.json(), indent=2))
         raise Exception(f"Query failed to run with a {r.status_code}.")
@@ -970,7 +1004,7 @@ def run(opts: dict, **kwargs):
         )
     else:
         _LOGGER.info("Starting single platform build")
-        build_single_arch(
+        image = build_single_arch(
             client,
             dir.name,
             tag=opts["tag"],
@@ -978,6 +1012,9 @@ def run(opts: dict, **kwargs):
             static_url=opts["static_url"],
         )
 
+        if opts["push"]:
+            push_image(client, image)
+
     cleanup_build(dir)
 
     if network:
